@@ -41,6 +41,9 @@ class List:
         except:
             return None
     
+    def forEach(self, fn): 
+        for i in self.contents: fn(i)
+    
     def __str__(self) -> str:
         text = "" + "["
         spacer = ", "
